A set of pure python routines to write KitWare VTK files.

This are just conveniencies that I use and other may find usefull.

You might also be interested in packages like:
  - `meshio <https://github.com/nschloe/meshio>`_ (more general)
  - `uvw <https://github.com/prs513rosewood/uvw>`_ (much closer in its *spirit*)

As of version 0.0.1 all routines are in a single (and much too big) file and CI is not really set up.
